@@ -65,7 +65,7 @@ class CSVData(SpreadSheetDataMixin, BaseData):
         self._selected_data_format = options.get("data_format", "dataframe")
         self._delimiter = options.get("delimiter", None)
         self._selected_columns = options.get("selected_columns", list())
-        self._header = options.get("header", 0)  # 0 for pandas to auto get
+        self._header = options.get("header", 'auto')
         self._checked_header = "header" in options
         self._default_delimiter = ','
 
@@ -86,6 +86,24 @@ class CSVData(SpreadSheetDataMixin, BaseData):
     def header(self):
         return self._header
 
+    def _check_and_return_options(self, options):
+        """
+        Ensures options are valid inputs to the data reader.
+
+        :param options: dictionary of options for the csv reader to validate
+        :type options: dict
+        :return: None
+        """
+        options = super()._check_and_return_options(options)
+        for key, value in options.items():
+            if key == 'header' and value != 'auto' and value is not None \
+                    and not (isinstance(value, int) and value > -1):
+                raise ValueError('`header` must be one of following: auto, '
+                                 'none for no header, or a non-negative '
+                                 'integer for the row that represents the '
+                                 'header (0 based index)')
+        return options
+
     @staticmethod
     def _determine_delimiter_of_str(data_as_str):
         """
@@ -136,8 +154,11 @@ class CSVData(SpreadSheetDataMixin, BaseData):
         
         # Determine type for every cell
         header_check_list = []
+        only_string_flag = True # Requires additional checks
         for row in data_as_str.split('\n'):
-            row_list = row.split(delimiter)
+            row_list = list(csv.reader([row],
+                                       delimiter=delimiter,
+                                       quotechar='"'))[0]
             header_check_list.append([])
 
             for i in range(len(row_list)):
@@ -148,28 +169,29 @@ class CSVData(SpreadSheetDataMixin, BaseData):
                     cell_type = 'none'
                 else:
             
-                    if cell.isdigit():
-                        cell_type = 'int'
-                        
-                    try:
-                        float(cell)
-                        cell_type = 'float'
-                    except ValueError:
-                        pass
-
                     try: 
-                        if dateutil.parser.parse(cell):
+                        if dateutil.parser.parse(cell, fuzzy=False):
                             cell_type = 'date'
                     except ValueError:
                         pass
                     except OverflowError:
                         pass
+
+                    try:
+                        f_cell = float(cell)
+                        cell_type = 'float'
+                        if f_cell.is_integer():
+                            cell_type = 'int'
+                    except ValueError:
+                        pass
                     
                     if cell.isupper():
                         cell_type = 'upstr'
 
+                if cell_type not in ['str', 'none']:
+                    only_string_flag = False
                 header_check_list[-1].append(cell_type)
-            
+                
         # Flags differences in types between each row (true/false)
         potential_header = header_check_list[0]
         differences = []
@@ -200,17 +222,23 @@ class CSVData(SpreadSheetDataMixin, BaseData):
         row_classic_header_ends = None
         change_flag = False
         for i in range(0, len(differences)):
-        
+
+            # Skip if there's nothing in the given row
+            if len(header_check_list[i]) == 0:
+                continue
+            
             # Determine ratio of none in row, must be BELOW threshold
             none = float(header_check_list[i].count("none")) / float(len(header_check_list[i]))
         
             # Determine percent of differences between prior row, must be BELOW threshold
             diff = float(differences[i].count(True)) / float(len(differences[i]))
         
-            # Determine percent of string, uppercase string or none in row, must be ABOVE threshold
+            # Determine percent of string, uppercase string or none in row,
+            # must be ABOVE threshold
             rstr = float((header_check_list[i].count("str") 
                           + header_check_list[i].count("upstr")
-                          + header_check_list[i].count("none"))) / float(len(header_check_list[i]))
+                          + header_check_list[i].count("none")))
+            rstr /= float(len(header_check_list[i]))
             
             # Determines if the number of elements in the row is increasing or decreasing
             len_increase = False
@@ -220,7 +248,7 @@ class CSVData(SpreadSheetDataMixin, BaseData):
                 len_increase = True
                 
             # Returns the last row that could reasonably be the header
-            if (rstr > str_thresh and none <= none_thresh and diff <= diff_thresh):
+            if (rstr > str_thresh and none < none_thresh and diff < diff_thresh):
                 if len_increase and not change_flag:
                     row_classic_header_ends = i
 
@@ -231,16 +259,74 @@ class CSVData(SpreadSheetDataMixin, BaseData):
         # If change in statistics never occurs, return no header
         if not change_flag:
             row_classic_header_ends = None
-                    
-        return row_classic_header_ends
 
 
+        # Attempt to resolve case where only strings in every cell
+        if only_string_flag:
+            col_stats = {}
+            rows = data_as_str.split('\n')
+            for i in range(0, len(rows)):
+                cells = list(csv.reader([rows[i]],
+                                        delimiter=delimiter,
+                                        quotechar='"'))[0]
+                for j in range(0, len(cells)):
+
+                    # Determine number of words in cell
+                    word_count = 0
+                    if len(cells[j].strip()) > 0:
+                        words = cells[j].strip().split(' ')
+                        word_count = len(words)
+                    
+                    # First row, set base
+                    if j not in col_stats:
+                        col_stats[j] = {"max":word_count, "min":word_count}
+
+                    # Identify min / max for a column
+                    if word_count > col_stats[j]['max']:
+                        col_stats[j]['max'] = word_count
+                    if word_count < col_stats[j]['min']:
+                        col_stats[j]['min'] = word_count
+
+                    # First index with value
+                    if 'first_index_with_value' not in col_stats[j] and word_count > 0:
+                        col_stats[j]['first_index_with_value'] = i
+
+            # Identify columns with variance
+            variance = [False] * len(col_stats.keys())
+            last_row_with_first_col_value = 0
+            last_row_with_first_col_value_count = 0
+            for i in col_stats.keys():
+                col = col_stats[i]
+                
+                # Determines if there's variance in the column
+                if (col['max'] - col['min']) > 1:
+                    variance[i] = True
+
+                # First last row, keeps a count of new col first in row
+                if 'first_index_with_value' in col:
+                    if col['first_index_with_value'] > last_row_with_first_col_value:
+                        last_row_with_first_col_value = col['first_index_with_value']
+                        last_row_with_first_col_value_count = 1
+                    elif col['first_index_with_value'] == last_row_with_first_col_value:
+                        last_row_with_first_col_value_count += 1
+
+            # Ensures there is at least some variance
+            if variance.count(True) > 0: 
+                
+                # Ensures most first lines are the same row
+                if last_row_with_first_col_value_count > (len(variance) // 2):
+                    row_classic_header_ends = last_row_with_first_col_value
+
+        return row_classic_header_ends
+
     def _load_data_from_str(self, data_as_str):
         """Loads the data into memory from the str."""
         if not self._delimiter:
             self._delimiter = self._determine_delimiter_of_str(data_as_str)
         data_buffered = StringIO(data_as_str)
-        self._guess_header_row(data_as_str, suggested_delim=self._delimiter)
+        if self._header == 'auto':
+            self._header = self._guess_header_row(
+                data_as_str, suggested_delim=self._delimiter)
         return data_utils.read_csv_df(
             data_buffered,
             self.delimiter, self.header, self.selected_columns,
@@ -257,7 +343,7 @@ class CSVData(SpreadSheetDataMixin, BaseData):
                 data_as_str = ''.join(check_lines)
             if not self._delimiter:
                 self._delimiter = self._determine_delimiter_of_str(data_as_str)            
-            if not self._header:
+            if self._header == 'auto':
                 self._header = self._guess_header_row(data_as_str, self._delimiter)
                 self._checked_header = True
 
@@ -309,8 +395,8 @@ class CSVData(SpreadSheetDataMixin, BaseData):
         file_encoding = data_utils.detect_file_encoding(file_path=file_path)
         delimiter = options.get("delimiter", None)
 
-        header = options.get("header", None)
-        if not delimiter or not header:
+        header = options.get("header", 'auto')
+        if not delimiter or header == 'auto':
 
             data_as_str = None
             with open(file_path, encoding=file_encoding) as csvfile:
@@ -321,8 +407,9 @@ class CSVData(SpreadSheetDataMixin, BaseData):
             if not delimiter:
                 delimiter = cls._determine_delimiter_of_str(data_as_str)
 
-            if header is None:
-                options.update(header=cls._guess_header_row(data_as_str, delimiter))
+            if header == 'auto':
+                options.update(header=cls._guess_header_row(data_as_str,
+                                                            delimiter))
 
         max_line_count = 1000
         min_line_count = 3
